==> spectrojack-0.3.tar.gz: spectrojack-0.3/help.h <==
"Commands (type them in the text zone near the start menu):",
"  f <freq>: set min freq displayed",
"  F <freq>: set max freq displayed",
"  d <dB>: set min dB",
"  D <dB>: set max dB",
"  l <sample count>: run a FFT each 'sample count'",
"  s <fft size>: set FFT size (from 128 to 524288, multiple of 2 only)",
"  o <overlap (in [0-1]): set FFT overlap factor (0: no ov., 1: full ov.)",
"    (note that setting to 1 won't give full ov., 1 sample will be advanced",
"     at each iteration, which will go very very fast, don't put such a value)",
"  w <window type>: set FFT window type",
"    window type is one of:",
"      nn: none (square window)",
"      ba: Bartlett (triangular)",
"      bl: Blackman",
"      hm: Hamming",
"      hn: Hanning",
"  c <file name>: load colormap",
"  cs: open colormap selection window",
"  nr: set display method to 'nearest' (default)",
"  av: set display method to 'average'",
"  p: pause/unpause",
"  h | help: print help",
"  q: quit",
"",
"Mouse actions in the main window:",
"  shift+click then move left/right:",
"    set the min or max freq displayed depending on where you click",
"    (upper/lower part of window)",
"    (equivalent to 'f' and 'F' commands)",
"  ctrl+click then move up/down:",
"    set the speed",
"    (equivalent to the 'l' command)",
"  move: scroll the view vertically",
"  click right button: popup menu",
"",
"Mouse actions in the green/red/orange window:",
"  left click: reset to green",
"  right click: reset the dB/t display (which contains the min/max dB",
"               encountered so far, accumulative, dB/s is min/max dB",
"               for the last second of run)",
"",
"Mouse actions in the colors window:",
"  click then move up/down:",
"    set the min/max dB displayed (experiment, it will become clear)",
"    (click upper part to change dB max, lower part to change dB min)",
"    (equivalent to 'd' and 'D' commands)",
"",
"Released in the public domain.",
"http://sed.free.fr/spectrojack",

==> spectrojack-0.4.tar.gz: spectrojack-0.4/help.h <==
"Commands (type them in the text zone near the start menu):",
"  f <freq>: set min freq displayed",
"  F <freq>: set max freq displayed",
"  d <dB>: set min dB",
"  D <dB>: set max dB",
"  l <sample count>: run a FFT each 'sample count'",
"  s <fft size>: set FFT size (from 128 to 524288, multiple of 2 only)",
"  o <overlap (in [0-1]): set FFT overlap factor (0: no ov., 1: full ov.)",
"    (note that setting to 1 won't give full ov., 1 sample will be advanced",
"     at each iteration, which will go very very fast, don't put such a value)",
"  w <window type>: set FFT window type",
"    window type is one of:",
"      nn: none (square window)",
"      ba: Bartlett (triangular)",
"      bl: Blackman",
"      hm: Hamming",
"      hn: Hanning",
"  c <file name>: load colormap",
"  cs: open colormap selection window",
"  nr: set display method to 'nearest' (default)",
"  av: set display method to 'average'",
"  fps <frames per second>: set the display refresh rate",
"  p: pause/unpause",
"  h | help: print help",
"  q: quit",
"",
"Mouse actions in the main window:",
"  shift+click then move left/right:",
"    set the min or max freq displayed depending on where you click",
"    (upper/lower part of window)",
"    (equivalent to 'f' and 'F' commands)",
"  ctrl+click then move up/down:",
"    set the speed",
"    (equivalent to the 'l' command)",
"  click left then move: scroll the view vertically",
"  click right button: popup menu",
"",
"Mouse actions in the green/red/orange window:",
"  left click: reset to green",
"  right click: reset the dB/t display (which contains the min/max dB",
"               encountered so far, accumulative, dB/s is min/max dB",
"               for the last second of run)",
"",
"Mouse actions in the colors window:",
"  click then move up/down:",
"    set the min/max dB displayed (experiment, it will become clear)",
"    (click upper part to change dB max, lower part to change dB min)",
"    (equivalent to 'd' and 'D' commands)",
"",
"Loading a file at startup:",
"  running 'spectrojack -f <file>' loads the file at startup.",
"  The file contains commands, like:",
"    s 4096",
"    l 1024",
"    o 0.5",
"    w bl",
"    c /usr/share/spectrojack/sonic_Black_on_White.txt",
"    av",
"  Comments are available, start with '#' up to end of line.",
"  See preset_example.txt in the sources to get a full example.",
"",
"Released in the public domain.",
"http://sed.free.fr/spectrojack",
